@@ -3,8 +3,10 @@
 Authentication backend for handling firebase user.idToken from incoming
 Authorization header, verifying, and locally authenticating
 """
+
 import json
 import uuid
+import sys
 import firebase_admin
 
 from firebase_admin import auth
@@ -16,10 +18,14 @@ from django.utils import timezone
 from rest_framework import HTTP_HEADER_ENCODING, exceptions
 
 settings_auth = settings.AUTHENTICATION
-firebase_credentials = firebase_admin.credentials.Certificate(
-    settings_auth["FIREBASE_SERVICE_ACCOUNT_KEY"]
-)
-firebase = firebase_admin.initialize_app(firebase_credentials)
+if 'test' in sys.argv:
+    firebase_credentials = None
+    firebase = None
+else:
+    firebase_credentials = firebase_admin.credentials.Certificate(
+        settings_auth["FIREBASE_SERVICE_ACCOUNT_KEY"]
+    )
+    firebase = firebase_admin.initialize_app(firebase_credentials)
 
 
 class TonicAuthentication():
@@ -88,7 +94,7 @@ class TonicAuthentication():
             if prefix == 'CWT' and token.decode('utf-8') in settings_auth["CUSTOM_WEB_TOKEN"].keys():
                 return settings_auth['CUSTOM_WEB_TOKEN'][token.decode('utf-8')]
 
-            if prefix == 'TWT' and token.decode('utf-8') in settings_auth['TONIC_WEB_TOKEN']:
+            if prefix == 'TWT' and token.decode('utf-8') == settings_auth['TONIC_WEB_TOKEN']:
                 return {
                     'name': 'Tonic Admin',
                     'is_admin': True,
