@@ -1,6 +1,14 @@
 from rest_framework import permissions
 
 
+class IsAuthenticated(permissions.BasePermission):
+    def has_permission(self, request, view):
+        """
+        Allows access only to authenticated users with uid.
+        """
+        return bool(request.user and 'uid' in request.user.keys())
+
+
 class IsLoggedInAndOwner(permissions.BasePermission):
     def has_permission(self, request, view):
         kwargs = request.parser_context['kwargs']
@@ -44,6 +52,6 @@ def get_user_id(kwargs):
 class IsCustomUserPermission(permissions.BasePermission):
     def has_permission(self, request, view):
         for name in view.custom_permissions:
-            if name == request.user:
+            if name == request.user['name']:
                 return True
         return False
